match_filter.family.Family
==========================

.. currentmodule:: eqcorrscan.core.match_filter.family

.. autoclass:: Family

   .. rubric:: Methods

   .. autosummary::

      append
      copy
      lag_calc
      plot
      sort
      write

   .. automethod:: __init__
   .. automethod:: append
   .. automethod:: copy
   .. automethod:: lag_calc
   .. automethod:: plot
   .. automethod:: sort
   .. automethod:: write
